#ifndef POTHPP
#define POTHPP
#include "box.hpp"
#include "limit.hpp"
#include "graphics.hpp"
#include "events.hpp"
#include "legend.hpp"
#include "database.hpp"
#include <stdio.h>
#include <string.h>

#define POT_LEGEND_HEIGHT 17
#define MAX_POT_ATTENUATION -102		// attenuation in dB

class Pot: public Icon {

public:

	friend class Cursor;

	char legend [MAX_LEGEND_LENGTH + 1];
	ShadedBox* pot_box;
	Cursor* cursor;
	float* pot_setting;
	void (*activation_function)();
	float minimum, maximum;
	char* units;

	COLOR_TYPE shade_color;
	COLOR_TYPE border_color;
	COLOR_TYPE legend_color;
	COLOR_TYPE legend_backdrop_color;
	COLOR_TYPE inactive_color;
	COLOR_TYPE active_color;
	COLOR_TYPE fill_color;

	Pot(int, int, int, int,
	    int, int, int, int,
	    float, float, char*,
	    int, int,
	    char*, float*, void (*) (),
	    COLOR_TYPE, COLOR_TYPE, COLOR_TYPE,
	    COLOR_TYPE, COLOR_TYPE);
	virtual void Display();
	void Setting(float value);
	float Setting() 		{return *pot_setting;}
	virtual void SettingDisplay();
	virtual ~Pot();
};


#define VERTICAL_POT_WIDTH 80
#define VERTICAL_POT_HEIGHT 100
#define VERTICAL_POT_CURSOR_WIDTH (VERTICAL_POT_WIDTH - 5)
#define VERTICAL_POT_CURSOR_HEIGHT 10

class VerticalPot: public Pot {

public:

	VerticalPot(int x, int y,
		    float min, float max, char* units,
		    char* name, float* value, void (*)() );

	virtual void SettingDisplay() {Pot::SettingDisplay();}
};


class AttenuatorPot: public VerticalPot {

public:

	AttenuatorPot(int x, int y, char* l, float* v, 
			    void (*)() );
};



#define TONE_MIN_LEVEL (-20)
#define TONE_MAX_LEVEL (20)

class ToneLevelPot: public VerticalPot {

public:

	ToneLevelPot(int x, int y, char* l, float* v, 
			   void (*) () );
};


#define HORIZONTAL_POT_WIDTH 100
#define HORIZONTAL_POT_HEIGHT 60
#define HORIZONTAL_POT_CURSOR_HEIGHT \
	(HORIZONTAL_POT_HEIGHT - (2 * POT_LEGEND_HEIGHT) - 5)
#define HORIZONTAL_POT_CURSOR_WIDTH 10

class HorizontalPot: public Pot {

public:

	HorizontalPot(int x, int y,
		      float min, float max, char* units,
		      char* name, float* value, void (*)() );

	 virtual void SettingDisplay() {Pot::SettingDisplay();}
};



class Cursor: public Icon {

	Pot* parent;

	int minimum_x, minimum_y;
	int maximum_x, maximum_y;
	int width, height;

	COLOR_TYPE shade_color;
	COLOR_TYPE border_color;
	COLOR_TYPE fill_color;
	COLOR_TYPE background_color;

	void Blank();
	void DisplayOutline();
	void UnDisplayOutline();

public:

	Cursor(Pot*, int, int, int, int, int, int,
	       COLOR_TYPE);
	void Display();
	void LeftButtonPressed();
	void LeftButtonReleased();
	void LeftButtonDragged(unsigned delta_x,
			       unsigned delta_y,
			       int status);
};

#endif
